@@ -7,7 +7,7 @@ class ShortType(ISerializable):
         return 2
 
     def serialize(self, value, buffer, registry):
-        buffer.putShort(value)
+        buffer.putShort(value if isinstance(value, int) else int(value))
 
     def deserialize(self, buffer, registry):
         return buffer.getShort()
